@@ -13,13 +13,11 @@ Alien::Tidyp - Build and make available tidyp library - L<http://www.tidyp.com>
 
 =cut
 
-our $VERSION = '0.99.7';
+our $VERSION = '1.0.1';
 
 =head1 VERSION
 
-Version 0.99.7 of Alien::Tidyp uses I<tidyp> sources v0.99 + some patches.
-
-Specifically this commit: L<http://github.com/petdance/tidyp/commit/749825bc9>
+Version 1.0.1 of Alien::Tidyp uses I<tidyp> sources v1.0.
 
 =head1 SYNOPSIS
 
